==========
zc.catalog
==========

.. image:: https://img.shields.io/pypi/v/zc.catalog.svg
   :target: https://pypi.org/project/zc.catalog/
   :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/zc.catalog.svg
   :target: https://pypi.org/project/zc.catalog/
   :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/zc.catalog/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/zopefoundation/zc.catalog/actions/workflows/tests.yml
   :alt: Build Status

.. image:: https://coveralls.io/repos/github/zopefoundation/zc.catalog/badge.svg
   :target: https://coveralls.io/github/zopefoundation/zc.catalog
   :alt: Code Coverage


zc.catalog is an extension to the Zope 3 catalog, Zope 3's indexing
and search facility. zc.catalog contains a number of extensions to the
Zope 3 catalog, such as some new indexes, improved globbing and
stemming support, and an alternative catalog implementation.
